# Contributing

First off, thank you for considering contributing to discreetly!

This document could use some contributions to make it useful. How meta!

We definitely want contributions in the form of:

- documentation
  - end-user
    - usage
    - recommendations for usage (i.e. setting up profiles, using multiple keys, different permissions, etc)
  - developer
    - how to contribute a new backend (e.g. azure?)
- code
  - test coverage for gcp
  - new features like improved/new backends
  - bug-fixes

In the meantime, some references for a good CONTRIBUTING.md:

- https://github.com/nayafia/contributing-template/blob/master/CONTRIBUTING-template.md
- https://mozillascience.github.io/working-open-workshop/contributing/
